summaryrefslogtreecommitdiff
path: root/indra/newview/llfloateroutbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llfloateroutbox.h')
-rwxr-xr-xindra/newview/llfloateroutbox.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/indra/newview/llfloateroutbox.h b/indra/newview/llfloateroutbox.h
index 1b1e1e0439..e28fb320ea 100755
--- a/indra/newview/llfloateroutbox.h
+++ b/indra/newview/llfloateroutbox.h
@@ -1,8 +1,8 @@
/**
* @file llfloateroutbox.h
* @brief Implementation of the merchant outbox window and of the merchant items window
*
* *TODO : Eventually, take out all the merchant outbox stuff and rename that file to llfloatermerchantitems
*
* $LicenseInfo:firstyear=2001&license=viewerlgpl$
* Second Life Viewer Source Code
@@ -115,14 +115,14 @@ private:
};
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-// Class LLFloaterMerchantItems
+// Class LLFloaterMarketplaceListings
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-class LLFloaterMerchantItems : public LLFloater
+class LLFloaterMarketplaceListings : public LLFloater
{
public:
- LLFloaterMerchantItems(const LLSD& key);
- ~LLFloaterMerchantItems();
+ LLFloaterMarketplaceListings(const LLSD& key);
+ ~LLFloaterMarketplaceListings();
void initializeMarketPlace();
@@ -1,8 +1,8 @@
/**
* @file llfloateroutbox.h
- * @brief Implementation of the merchant outbox window and of the merchant items window
+ * @brief Implementation of the merchant outbox window and of the marketplace listings window
*
@@ -1,8 +1,8 @@
*
- * *TODO : Eventually, take out all the merchant outbox stuff and rename that file to llfloatermerchantitems
+ * *TODO : Eventually, take out all the merchant outbox stuff and rename that file to llfloatermarketplacelistings
*
* $LicenseInfo:firstyear=2001&license=viewerlgpl$